@@ -3,10 +3,7 @@
 	  PARAMETER (NX=100, NY=100, LEVEL=256)
       REAL R(NX,NY),B(NX,NY),G(NX,NY)
       REAL RC(NX,NY),BC(NX,NY),GC(NX,NY)
-      REAL CL(LEVEL)
-      INTEGER IR(LEVEL),IG(LEVEL),IB(LEVEL)
       INTEGER I
-      INTEGER IMAGE(300)
 
 	  do i=1,nx
 		do j=1,ny
