@@ -10,13 +10,16 @@
 
       CALL SWQFCC(LFCATR)
       CALL SWLGET('LCMCH',LCMCH)
+      CALL SWIGET('IWS', IWS)
+      IF ((IWS.GE.1).AND.(IWS.LE.4)) THEN
       IF (LCMCH) THEN
-      IF (.NOT.LFCATR) THEN
-        CALL MSGDMP('W','SGSCMN',
-     *       'COLORMAP MIGHT NOT CHANGE IMMEDIATELY.')
-      ENDIF
+        IF ((.NOT.LFCATR).OR.(IWS.EQ.1)) THEN
+          CALL MSGDMP('W','SGSCMN',
+     *         'COLORMAP MIGHT NOT CHANGE IMMEDIATELY.')
+        ENDIF
         CALL SWCLCH()
       ENDIF
+      ENDIF
       RETURN
 *-----------------------------------------------------------------------
       ENTRY SGQCMN(NMAX)
