@@ -5,10 +5,9 @@
 
       PARAMETER (MAXP=3,MAXF=3)
 
-      LOGICAL   LCHREQ
       CHARACTER CPLIST(MAXP)*80,CFLIST(MAXF)*80,CPX*80
 
-      EXTERNAL  LENC,LCHREQ
+      EXTERNAL  LENC
 
 
       CPLIST(1)=' '
