@@ -3,9 +3,7 @@
  */
 #include <string.h>
 
-void cfnchr (ch1, ch2, lch)
-    char *ch1, *ch2;
-    int  lch;
+void cfnchr (char *ch1, char *ch2, int lch)
 {
     int nc;
     char *nl;
