@@ -29,7 +29,7 @@
       DATA      CPARAS(9)  / 'LPRINT  ' / , LX(9)  / .FALSE. /
       DATA      CPARAS(10) / 'LWND    ' / , LX(10) / .TRUE. /
       DATA      CPARAS(11) / 'LFGBG   ' / , LX(11) / .FALSE. /
-      DATA      CPARAS(12) / 'LCMCH   ' / , LX(12) / .FALSE. /
+      DATA      CPARAS(12) / 'LCMCH   ' / , LX(12) / .TRUE. /
 * ---- LONG NAME ----
       DATA      CPARAL(1)  / 'WAIT' /
       DATA      CPARAL(2)  / 'WAIT_OPENING' /
