@@ -93,8 +93,6 @@ static GdkColor cx[MAXCLI];
 static int ifunc, next;
 static int dumpz = FALSE;
 
-void zguprect(int,int);
-
 /*------------------------- GDK 設定 ------------------------*/
 
 void zgupdate(int flag)
@@ -186,6 +184,9 @@ gint zg_key_press_event(GtkWidget *widget, GdkEventKey *event)
 
   case PCLS:
     switch (event->keyval) {
+    case GDK_w:
+      wait_np = TRUE;
+      break;
     case GDK_Return:
     case GDK_space:
       next = TRUE;
@@ -361,6 +362,15 @@ static void zgbmcv(int *nx, int *ny, char bmline[], char bitmap[])
 }
 #endif
 
+/*---------------------internal function ------------------*/
+
+void zguprect(int ix, int iy)
+{
+	if ((ix-irwidth) < irxb || irxb == 0) irxb =ix-irwidth;
+	if ((ix+irwidth) > irxt ) irxt =ix+irwidth;
+	if ((iy-irwidth) < iryb || iryb == 0) iryb =iy-irwidth;
+	if ((iy+irwidth) > iryt ) iryt =iy+irwidth;
+}
 
 /*------------------------- device ------------------------*/
 void zgdopn_(DCL_INT *width, DCL_INT *height, DCL_INT *iposx, DCL_INT *iposy, 
@@ -1266,10 +1276,3 @@ void zgclini_(char clrmap[], DCL_INT *lfgbg)
    }
 
 }
-
-void zguprect(int ix,int iy){
-	if ((ix-irwidth) < irxb || irxb == 0) irxb =ix-irwidth;
-	if ((ix+irwidth) > irxt ) irxt =ix+irwidth;
-	if ((iy-irwidth) < iryb || iryb == 0) iryb =iy-irwidth;
-	if ((iy+irwidth) > iryt ) iryt =iy+irwidth;
-}
