@@ -20,8 +20,16 @@
         LFRST=.FALSE.
       END IF
 
-      IWDIDX=MOD(INDEX,10)
-      ICLIDX=MOD(INDEX/10,100)
+      CALL SGIGET('IBGCLI',IBGCLI)
+
+      IWDIDX=MOD(INDEXZ,10)
+      ICLIDX=INDEXZ/10
+      IF (ICLIDX.EQ.IBGCLI) THEN
+        ICLIDX=0
+      ELSE
+        ICLIDX=MOD(ICLIDX,100)
+        IF (ICLIDX.EQ.0) ICLIDX=1
+      END IF
 
       IF (.NOT.LCLATR .AND. IWDIDX.EQ.0) THEN
         IWDIDX=ICLIDX
@@ -30,7 +38,8 @@
       END IF
 
       CALL SWSWDI(IWDIDX)
-      CALL SWSCLI(ICLIDX)
+      CALL SWQFCC(LFCATR)
+      CALL SWSCLI(ICLIDX,LFCATR)
 
       RETURN
 *-----------------------------------------------------------------------
