@@ -12,7 +12,7 @@
       REAL      SX(NCMAX)
       LOGICAL   LSX,LSY
 
-      EXTERNAL  IMOD,IGUS,INDXIF,RMAX0,RMIN0,RD2R
+      EXTERNAL  IMOD,IGUS,INDXRF,RMAX0,RMIN0,RD2R
 
       SAVE
 
@@ -116,7 +116,7 @@
           CALL SZMVLV(X1,Y1)
           DO 25 J=1,NP
             SZ=RMIN0(SX,NP,1)
-            IZ=INDXIF(SX,NP,1,SZ)
+            IZ=INDXRF(SX,NP,1,SZ)
             XS=X1+SZ*(X2-X1)
             YS=Y1+SZ*(Y2-Y1)
             IF (MOD(J,2).NE.0) THEN
