@@ -1,5 +1,7 @@
 *-----------------------------------------------------------------------
 *     DRAW CONTINENTAL OUTLINES
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UMPOUT
 
@@ -14,7 +16,7 @@
         CALL UMPMAP('COAST_WORLD')
         CALL UMPMAP('BORDER_WORLD')
       ELSE
-        CALL MSGDMP('M','INVALID GROUP NUMBER / DO NOTHING.')
+        CALL MSGDMP('M','UMPOUT','INVALID GROUP NUMBER / DO NOTHING.')
         RETURN
       END IF
 
