@@ -18,6 +18,7 @@
 
       EXTERNAL  IUETON
 
+      CALL SGIGET('IBGCLI',IBGCLI)
 
 *     / CHECK IMAGE CAPABILITY /
 
@@ -115,6 +116,9 @@
      +             + (Z(IX, IY+1)*(1-FX) + Z(IX+1,IY+1)*FX)*FY
                 IF (TL1(1) .LE. ZZ .AND. ZZ .LE. TL2(NT)) THEN
                   IMAGE(I) = IUETON(ZZ)/1000
+                  IF(IMAGE(I) .EQ. IBGCLI) THEN
+                    IMAGE(I)=0
+                  ENDIF
                 ELSE
                   IMAGE(I) = 0
                 END IF
