@@ -1,11 +1,13 @@
 *-----------------------------------------------------------------------
 *     USCGET / USCSET / USCSTX
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE USCGET(CP,CPARA)
 
       CHARACTER CP*(*), CPARA*(*)
 
-      CHARACTER CX*8, CPVAL*80
+      CHARACTER CX*40, CPVAL*80
 
 
       CALL USCQID(CP,IDX)
@@ -22,11 +24,17 @@
 *-----------------------------------------------------------------------
       ENTRY USCSTX(CP, CPARA)
 
-      CX = CP
       CPVAL = CPARA
-      CALL RTCGET('US:', CX, CPVAL, 1)
-      CALL USCQID(CX,IDX)
-      CALL USCSVL(IDX,CPVAL)
+
+      CALL USCQID(CP, IDX)
+
+      CALL USCQCP(IDX, CX)
+      CALL RTCGET('US', CX, CPVAL, 1)
+
+      CALL USCQCL(IDX, CX)
+      CALL RLCGET(CX, CPVAL, 1)
+
+      CALL USCSVL(IDX, CPVAL)
 
       RETURN
       END
